@@ -136,6 +136,23 @@ class TestInstall(Basetest):
         exitCode=mwCluster.check()
         self.assertEqual(0,exitCode)
         
+    def testPortBindingAccess(self):
+        """
+        https://github.com/WolfgangFahl/pymediawikidocker/issues/48
+        
+        refactor port binding access 
+        """    
+        mwCluster=self.getMwCluster(withGenerate=False)
+        apps=mwCluster.apps.values()
+        for mwApp in apps:
+            self.assertTrue(mwApp.dbContainer is not None)
+            self.assertTrue(mwApp.mwContainer is not None)
+            browser_port=mwApp.mwContainer.getHostPort(80)
+            sql_port=mwApp.dbContainer.getHostPort(3306)
+            self.assertEqual(str(browser_port),str(mwApp.config.port))
+            self.assertEqual(str(sql_port),str(mwApp.config.sqlPort))
+            pass
+        
     def testSocketGetHostname(self):
         """
         test for https://github.com/python/cpython/issues/79345
@@ -189,11 +206,14 @@ class TestInstall(Basetest):
             "--basePort","9481",
             "--sqlBasePort","10307"]
         self.printCommand("--down -f",args)
+        forceRebuild=True
         mwCluster=self.getMwCluster(args,createApps=False)
         mwCluster.config.addExtensions(["MagicNoCache"])
-        apps=mwCluster.createApps(withGenerate=True)
+        mwCluster.config.forceRebuild=forceRebuild
+        mwCluster.config.reset_container_base_name()
+        apps=mwCluster.createApps(withGenerate=forceRebuild)
         app=apps[version]
-        app.start(forceRebuild=True)
+        app.start(forceRebuild=forceRebuild)
         exitCode=mwCluster.check()
         self.assertEqual(0,exitCode)
         
@@ -203,8 +223,12 @@ class TestInstall(Basetest):
         '''
         version="1.36.0"
         args=["--versionList",version,
-            "--prefix","mittest"
+            "--prefix","mittest",
+            "--container_name","mittest",
+            "-f"
         ]
+        debug=self.debug
+        debug=True
         try:
             mwCluster=self.getMwCluster(args,createApps=True)
             mwCluster.start()
@@ -212,10 +236,10 @@ class TestInstall(Basetest):
             self.assertEqual(0,exitCode)
         except Exception as ex:
             ex_msg=str(ex)
-            if self.debug:
-                print(ex_msg)
+            if debug:
+                print(f"exception: {ex_msg}")
             #self.assertTrue()
-            self.assertTrue("code 14" in ex_msg)
+            self.assertTrue("code 14" in ex_msg,ex_msg)
             pass
            
     def testWikiUser(self):
@@ -227,6 +251,7 @@ class TestInstall(Basetest):
             wikiUser=mwApp.createWikiUser(store=False)
             if self.debug:
                 print(wikiUser)
+            self.assertEqual(wikiUser.wikiId,mwApp.config.container_base_name)
             pass
         
     def testMwClusterCommandLine(self):
